@@ -5,6 +5,7 @@ use std::collections::HashMap;
 use std::fs::File;
 use std::io::{Error, ErrorKind, Write};
 use std::path::Path;
+use std::sync::LazyLock;
 
 use chrono::{DateTime, Duration, Utc};
 use serde::{Deserialize, Serialize};
@@ -23,16 +24,14 @@ use super::logfiles_manager::LogfilesManager;
 use super::opt::{Opt, MIN_TIMELINE_STEPS};
 use super::timelines::{get_duration_text, MinMeanMax};
 
-pub const SAFENODE_BINARY_NAME: &str = "safenode";
+pub const NODE_BINARY_NAME: &str = "safenode";
 pub static SUMMARY_WINDOW_NAME: &str = "Summary of Monitored Nodes";
 pub static HELP_WINDOW_NAME: &str = "Help";
 pub static DEBUG_WINDOW_NAME: &str = "Debug Window";
 
 use std::sync::Mutex;
-lazy_static::lazy_static! {
-	pub static ref DEBUG_LOGFILE: Mutex<Option<NamedTempFile>> =
-		Mutex::<Option<NamedTempFile>>::new(None);
-}
+static DEBUG_LOGFILE: LazyLock<Mutex<Option<NamedTempFile>>> =
+	LazyLock::new(|| Mutex::<Option<NamedTempFile>>::new(None));
 
 #[macro_export]
 macro_rules! debug_log {
@@ -59,15 +58,11 @@ pub unsafe fn debug_log(message: &str) {
 	};
 }
 
-lazy_static::lazy_static! {
-	pub static ref OPT: Mutex<Opt> =
-		Mutex::<Opt>::new(Opt::from_args());
-}
+pub static OPT: LazyLock<Mutex<Opt>> = LazyLock::new(|| Mutex::<Opt>::new(Opt::from_args()));
 
-lazy_static::lazy_static! {
-	pub static ref WEB_PRICES: Mutex<super::web_requests::WebPrices> =
-		Mutex::<super::web_requests::WebPrices>::new(super::web_requests::WebPrices::new());
-}
+pub static WEB_PRICES: LazyLock<Mutex<super::web_requests::WebPrices>> = LazyLock::new(|| {
+	Mutex::<super::web_requests::WebPrices>::new(super::web_requests::WebPrices::new())
+});
 
 pub struct App {
 	pub dash_state: DashState,
@@ -803,7 +798,7 @@ impl LogMonitor {
 		checkpoint_interval: u64,
 	) -> Result<String, std::io::Error> {
 		self.metrics.parser_output = format!("LogMeta::decode_metadata() failed on: {}", line); // For debugging
-																																												// debug_log!(&self.parser_output.clone());
+																																													// debug_log!(&self.parser_output.clone());
 
 		self.metrics.entry_metadata = LogEntry::decode_metadata(line);
 
@@ -852,7 +847,7 @@ impl LogMonitor {
 		after_time: Option<DateTime<Utc>>,
 	) -> Result<(), std::io::Error> {
 		self.metrics.parser_output = format!("LogMeta::decode_metadata() failed on: {}", line); // For debugging
-																																												// debug_log!(&self.parser_output.clone());
+																																													// debug_log!(&self.parser_output.clone());
 
 		if let Some(entry_metadata) = LogEntry::decode_metadata(line) {
 			if let Some(after_time) = after_time {
@@ -892,10 +887,12 @@ impl LogMonitor {
 }
 
 use regex::Regex;
-lazy_static::lazy_static! {
-	static ref LOG_LINE_PATTERN: Regex =
-		Regex::new(r"\[(?P<time_string>[^ ]{27}) (?P<category>[A-Z]{4,6}) (?P<source>[^\]]*)\] (?P<message>.*)").expect("The regex failed to compile. This is a bug.");
-}
+pub static LOG_LINE_PATTERN: LazyLock<Regex> = LazyLock::new(|| {
+	Regex::new(
+		r"\[(?P<time_string>[^ ]{27}) (?P<category>[A-Z]{4,6}) (?P<source>[^\]]*)\] (?P<message>.*)",
+	)
+	.expect("The regex failed to compile. This is a bug.")
+});
 
 #[derive(PartialEq, Clone, Default, Debug, Serialize, Deserialize)]
 pub enum NodeStatus {
@@ -973,7 +970,7 @@ pub struct NodeMetrics {
 	pub activity_gets: MmmStat,
 	pub activity_puts: MmmStat,
 	pub activity_errors: MmmStat,
-	pub nanos_earned: MmmStat,
+	pub attos_earned: MmmStat,
 	pub storage_cost: MmmStat,
 	pub peers_connected: MmmStat,
 	pub memory_used_mb: MmmStat,
@@ -1030,7 +1027,7 @@ impl NodeMetrics {
 			activity_errors: MmmStat::new(),
 
 			// Storage Payments
-			nanos_earned: MmmStat::new(),
+			attos_earned: MmmStat::new(),
 			storage_cost: MmmStat::new(),
 			peers_connected: MmmStat::new(),
 
@@ -1115,7 +1112,7 @@ impl NodeMetrics {
 		self.memory_used_mb = MmmStat::new();
 	}
 
-	///! Process a line from a SAFE Node logfile.
+	///! Process a line from a  Node logfile.
 	///! Use a created LogMeta to update metrics.
 	pub fn gather_metrics(&mut self, line: &str) -> Result<(), std::io::Error> {
 		let entry = LogEntry {
@@ -1219,9 +1216,9 @@ impl NodeMetrics {
 			};
 			return false; // Continue processing for records stored (parse_states())
 		} else if line.contains("after earning ") {
-			if let Some(nanos_earned) = self.parse_u64("after earning ", line) {
-				self.count_nanos_earned(entry_time, nanos_earned);
-				self.parser_output = format!("Payment received: {}", nanos_earned);
+			if let Some(attos_earned) = self.parse_u64("after earning ", line) {
+				self.count_attos_earned(entry_time, attos_earned);
+				self.parser_output = format!("Payment received: {}", attos_earned);
 				return true;
 			};
 		} else if line.contains("PeersInRoutingTable") {
@@ -1521,9 +1518,9 @@ impl NodeMetrics {
 		self.apply_timeline_sample(ERRORS_TIMELINE_KEY, time, 1);
 	}
 
-	fn count_nanos_earned(&mut self, time: &DateTime<Utc>, nanos_earned: u64) {
-		self.nanos_earned.add_sample(nanos_earned);
-		self.apply_timeline_sample(EARNINGS_TIMELINE_KEY, time, nanos_earned);
+	fn count_attos_earned(&mut self, time: &DateTime<Utc>, attos_earned: u64) {
+		self.attos_earned.add_sample(attos_earned);
+		self.apply_timeline_sample(EARNINGS_TIMELINE_KEY, time, attos_earned);
 	}
 
 	fn count_storage_cost(&mut self, time: &DateTime<Utc>, storage_cost: u64) {
